==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/packageableelement/impl/ElementVisibilitySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.packageableelement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.elementpackaging.EP_PKGSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.impl.EP_PKGSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ElementVisibility;
import io.ciera.tool.sql.ooaofooa.packageableelement.ElementVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.SearchResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.SearchResultSetSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ElementTypeConstants;


public class ElementVisibilitySetImpl extends InstanceSet<ElementVisibilitySet,ElementVisibility> implements ElementVisibilitySet {

    // attributes
    @Override
    public void setType( ElementTypeConstants ref_Type ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setType( ref_Type );
    }
    @Override
    public void setPackage_ID( UniqueId ref_Package_ID ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setPackage_ID( ref_Package_ID );
    }
    @Override
    public void setVisibility_ID( UniqueId m_Visibility_ID ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setVisibility_ID( m_Visibility_ID );
    }
    @Override
    public void setElement_ID( UniqueId ref_Element_ID ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setElement_ID( ref_Element_ID );
    }
    @Override
    public void setName( String ref_Name ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setName( ref_Name );
    }


    // selections
    @Override
    public PackageableElementSet R8002_has_visibility_of_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ElementVisibility elementvisibility : this ) packageableelementset.add( elementvisibility.R8002_has_visibility_of_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public EP_PKGSet R8002_is_visible_to_elements_in_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( ElementVisibility elementvisibility : this ) ep_pkgset.add( elementvisibility.R8002_is_visible_to_elements_in_EP_PKG() );
        return ep_pkgset;
    }
    @Override
    public SearchResultSetSet R8006_SearchResultSet() throws XtumlException {
        SearchResultSetSet searchresultsetset = new SearchResultSetSetImpl();
        for ( ElementVisibility elementvisibility : this ) searchresultsetset.add( elementvisibility.R8006_SearchResultSet() );
        return searchresultsetset;
    }


    @Override
    public ElementVisibility nullElement() {
        return ElementVisibilityImpl.EMPTY_ELEMENTVISIBILITY;
    }

    @Override
    public ElementVisibilitySet emptySet() {
      return new ElementVisibilitySetImpl();
    }

    @Override
    public ElementVisibilitySet value() {
        return this;
    }

    @Override
    public List<ElementVisibility> elements() {
        ElementVisibility[] elements = toArray(new ElementVisibility[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/packageableelement/impl/ElementVisibilitySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.packageableelement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.elementpackaging.EP_PKGSet;
import io.ciera.tool.sql.ooaofooa.elementpackaging.impl.EP_PKGSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ElementVisibility;
import io.ciera.tool.sql.ooaofooa.packageableelement.ElementVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.SearchResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.SearchResultSetSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ElementTypeConstants;


public class ElementVisibilitySetImpl extends InstanceSet<ElementVisibilitySet,ElementVisibility> implements ElementVisibilitySet {

    public ElementVisibilitySetImpl() {
    }

    public ElementVisibilitySetImpl(Comparator<? super ElementVisibility> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setElement_ID( UniqueId ref_Element_ID ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setElement_ID( ref_Element_ID );
    }
    @Override
    public void setVisibility_ID( UniqueId m_Visibility_ID ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setVisibility_ID( m_Visibility_ID );
    }
    @Override
    public void setName( String ref_Name ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setName( ref_Name );
    }
    @Override
    public void setType( ElementTypeConstants ref_Type ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setType( ref_Type );
    }
    @Override
    public void setPackage_ID( UniqueId ref_Package_ID ) throws XtumlException {
        for ( ElementVisibility elementvisibility : this ) elementvisibility.setPackage_ID( ref_Package_ID );
    }


    // selections
    @Override
    public PackageableElementSet R8002_has_visibility_of_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ElementVisibility elementvisibility : this ) packageableelementset.add( elementvisibility.R8002_has_visibility_of_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public EP_PKGSet R8002_is_visible_to_elements_in_EP_PKG() throws XtumlException {
        EP_PKGSet ep_pkgset = new EP_PKGSetImpl();
        for ( ElementVisibility elementvisibility : this ) ep_pkgset.add( elementvisibility.R8002_is_visible_to_elements_in_EP_PKG() );
        return ep_pkgset;
    }
    @Override
    public SearchResultSetSet R8006_SearchResultSet() throws XtumlException {
        SearchResultSetSet searchresultsetset = new SearchResultSetSetImpl();
        for ( ElementVisibility elementvisibility : this ) searchresultsetset.add( elementvisibility.R8006_SearchResultSet() );
        return searchresultsetset;
    }


    @Override
    public ElementVisibility nullElement() {
        return ElementVisibilityImpl.EMPTY_ELEMENTVISIBILITY;
    }

    @Override
    public ElementVisibilitySet emptySet() {
      return new ElementVisibilitySetImpl();
    }

    @Override
    public ElementVisibilitySet emptySet(Comparator<? super ElementVisibility> comp) {
      return new ElementVisibilitySetImpl(comp);
    }

    @Override
    public ElementVisibilitySet value() {
        return this;
    }

    @Override
    public List<ElementVisibility> elements() {
        ElementVisibility[] elements = toArray(new ElementVisibility[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
